#
# spec file for package python-vcrpy
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2015 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-vcrpy
Version:        4.2.1
Release:        3.1
Summary:        Python module to mock and replay HTTP interactions
License:        MIT
URL:            https://github.com/kevin1024/vcrpy
Source:         https://files.pythonhosted.org/packages/source/v/vcrpy/vcrpy-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-httpbin}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.5}
# gh#kevin1024/vcrpy#688
BuildRequires:  %{python_module urllib3 < 2}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module wrapt}
BuildRequires:  %{python_module yarl}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-six >= 1.5
Requires:       python-urllib3 < 2
Requires:       python-wrapt
BuildArch:      noarch
Requires:       python-yarl
%python_subpackages

%description
This module records a test suite's HTTP interactions and replays them during future
test runs for deterministic tests.

This is a Python version of Ruby's VCR library.

%prep
%setup -q -n vcrpy-%{version}
# online integration tests
rm -r tests/integration

%build
export LANG=en_US.UTF-8
%pyproject_wheel

%install
export LANG=en_US.UTF-8
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/vcr

%check
# Skip TestVCRConnection.testing_connect. Attempts
# a real connection.
export LANG=en_US.UTF-8
%pytest -k "not testing_connect"

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/vcr
%{python_sitelib}/vcrpy-%{version}.dist-info

%changelog
* Thu Jun 15 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Tue May 23 2023 Ben Greiner <code@bnavigator.de>
- Restrict urllib3 < 2 -- gh#kevin1024/vcrpy#688
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 4.2.1
  * Fix a bug where the first request in a redirect chain was not being recorded with aiohttp
  * Various typos and small fixes, thanks @jairhenrique, @timgates42
* Thu Aug 26 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 4.1.1:
  * Fix HTTPX support for versions greater than 0.15 (thanks @jairhenrique)
  * Include a trailing newline on json cassettes (thanks @AaronRobson)
* Fri Aug 28 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.1.0:
  * Add support for httpx!! (thanks @herdigiorgi)
  * Add the new allow_playback_repeats option (thanks @tysonholub)
  * Several aiohttp improvements (cookie support, multiple headers with same
    key) (Thanks @pauloromeira)
  * Use enums for record modes (thanks @aaronbannin)
  * Bugfix: Do not redirect on 304 in aiohttp (Thanks @royjs)
  * Bugfix: Fix test suite by switching to mockbin (thanks @jairhenrique)
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove patch 0001-Revert-v4.0.x-Remove-legacy-python-and-add-python3.8.patch
  as we dropped py2 integration support on Tumbleweed
* Mon Feb 24 2020 Marketa Calabkova <mcalabkova@suse.com>
- Added patch 0001-Revert-v4.0.x-Remove-legacy-python-and-add-python3.8.patch
  * Enable python2 again since it breaks many packages
- Fix locale on Leap
* Fri Feb  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.0.2
  * Remove Python2 support
  * Add Python 3.8 TravisCI support
  * Correct mock imports
* Sun Nov  3 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.1
  * Format code with black
  * Improve documentation about custom matchers
  * Fix exception when body is empty
  * Fix yarl and python3.5 version issue
  * Fix header matcher for boto3
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.0:
  * Add a rewind method to reset a cassette (thanks @khamidou)
  * New error message with more details on why the cassette failed to play a request (thanks @arthurHamon2, @neozenith)
  * Handle connect tunnel URI (thanks @jeking3)
  * Drop support to python 3.4
  * Add deprecation warning on python 2.7, next major release will drop python 2.7 support
- Drop merged patch python-vcrpy-fix-tunnel-uri-generation.patch
* Wed Apr 17 2019 Matej Cepl <mcepl@suse.com>
- Test suite just doesn't work. gh#kevin1024/vcrpy#427
* Sat Dec 29 2018 mardnh@gmx.de
- Add patch:
  * python-vcrpy-fix-tunnel-uri-generation.patch
    Needed for python-pyvmomi
* Wed Oct 24 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary and adjust descriptions.
* Wed Oct 24 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 2.0.1:
  * Support python 3.7 (fix httplib2 and urllib2, thanks @felixonmars)
* Thu Jul 13 2017 sean.marlow@suse.com
- Move vcrpy to single spec.
* Thu Jun  8 2017 sean.marlow@suse.com
- Changes from version 1.11.1:
  * Bugfixes
  * Add support for latest requests and urllib3 releases
- Changes from version 1.11.0:
  * Allow injection of persistence methods
  * Bugfixes
  * Support python 3.6 + CI tests
  * Support pytest-asyncio coroutines
- Changes from version 1.10.5:
  * Added a fix to httplib2
  * Fix an issue with aiohttp
  * Add missing requirement yarl
  * Remove duplicate mock triple
- Changes from version 1.10.3:
  * Aiohttp bugfix
  * Empty cassette body bugfix
* Sun Sep 18 2016 mardnh@gmx.de
- Fix Source-URL
- Update to version 1.10.2:
  * only version bump - no code changes
- Changes from version 1.10.1
  * Move vcr.stubs.aiohttp_stub to a package
  * Merge pull request #271 from lamenezes/fix-py2-setup
  * Exclude aiohttp from python < 3 setup
- Changes from version 1.10.0:
  * remove py26-flakes test
  * fix flake8: ignore yield from syntax errors
  * fix tox's flakes tests
  * fix test_aiohttp
  * fix tests
  * remove async/await from aiohttp_stubs to support python 3.4
  * add aiohttp to tests config
  * add integration tests for aiohttp
  * fix aiohttp_stubs.vcr_request error message
  * fix aiohttp response closing
  * remove CIMultiDictProxy from aiohttp_stubs.vcr_request
  * add support for aiohttp
  * Merge pull request #265 from adamchainz/readthedocs.io
  * fix flaky test
  * Convert readthedocs links for their .org -> .io migration for hosted projects
- Changes from version 1.9.0:
  * unzip bodies before comparing.  Fixes #261
  * Merge pull request #247 from dedsm/boto3_support
  * Running boto3 tests in travis
  * Fixing pep8 errors in boto tests
  * boto3 integration tests
  * Adding support for boto3
  * fix tests in stubs, requests ssl verification and httpbin+flask
  * Removed requests usage from test
  * Renamed inside2 to inside
  * Fix flake8 issue
  * Updated comments
  * Added a note on the deepcopy
  * Added regression test
  * Move deepcopy higher to not mutate original headers
- Changes from version 1.8.0:
  * missed a httpbin call
  * Merge pull request #253 from jayvdb/no-pytest-localserver
  * Remove pytest-localserver from test dependencies
  * pep8
  * Fix for Serialization errors with JSON adapter
  * Use pytest-httpbin
  * Add Python 3.5 and PyPy 3 to Travis
  * Fix/ignore some flake errors
  * Add test to make sure we can post chunked binary data
  * Avoid concatenating bytes with strings
  * Fix travis check for flakes
  * allow filtering by response
  * Exclude __pycache__ dirs & compiled files in sdist
  * Fix Tornado support behavior for Tornado 3.
  * Use tox-travis
  * support python 3.4
  * tests / docs for decode_compressed_response
  * add decode_compressed_response option and filter
  * Fix pyflakes and pep8 errors
  * Use tox for Travis-CI
  * Fix typo
  * Add documentation for new features of filter_headers, filter_query_parameters and filter_post_data_parameters
  * Update VCR params to use new filters.
  * Add replace_post_data_parameters()
  * Add replace_query_parameters()
  * Add replace_headers()
  * Add note and link for vcrpy-unittest.
  * Blindly add modules to be documented
  * Add PyPI badge.
  * Rename waffle badge from 'ready' to 'waffle' which seems clearer.
  * Split README.rst into appropriate docs sections
  * Use sphinx_rtd_theme building docs locally
  * Switch to default RtD theme
  * Lint cleanup
  * Fallback to importing from urllib3
* Tue Jan 26 2016 bear454@opensuse.org
- Update to version 1.7.4:
  1.7.4 [#217] Make use_cassette decorated functions actually return a value (thanks @bcen). [#199] Fix path transfromation defaults. Better headers dictionary management.
  1.7.3 [#188] additional_matchers kwarg on use_cassette. [#191] Actually support passing multiple before_record_request functions (thanks @agriffis).
  1.7.2 [#186] Get effective_url in tornado (thanks @mvschaik), [#187] Set request_time on Response object in tornado (thanks @abhinav).
  1.7.1 [#183] Patch fetch_impl instead of the entire HTTPClient class for Tornado (thanks @abhinav).
  1.7.0 [#177] Properly support coroutine/generator decoration. [#178] Support distribute (thanks @graingert). [#163] Make compatibility between python2 and python3 recorded cassettes more robust (thanks @gward).
  1.6.1 [#169] Support conditional requirements in old versions of pip, Fix RST parse errors generated by pandoc, [Tornado] Fix unsupported features exception not being raised, [#166] content-aware body matcher.
  1.6.0 [#120] Tornado support (thanks @abhinav), [#147] packaging fixes (thanks @graingert), [#158] allow filtering post params in requests (thanks @MrJohz), [#140] add xmlrpclib support (thanks @Diaoul).
  1.5.2 Fix crash when cassette path contains cassette library directory (thanks @gazpachoking).
  1.5.0 Automatic cassette naming and ‘application/json’ post data filtering (thanks @marco-santamaria).
  1.4.2 Fix a bug caused by requests 2.7 and chunked transfer encoding
  1.4.1 Include README, tests, LICENSE in package. Thanks @ralphbean.
  1.4.0 Filter post data parameters (thanks @eadmundo), support for posting files through requests, inject_cassette kwarg to access cassette from use_cassette decorated function, with_current_defaults actually works (thanks @samstav).
  1.3.0 Fix/add support for urllib3 (thanks @aisch), fix default port for https (thanks @abhinav).
* Wed Feb  4 2015 hpj@urpla.net
- Update to version 1.2.0:
  * Add custom_patches argument to VCR/Cassette objects to allow
    users to stub custom classes when cassettes become active.
- Changes from version 2.1.4:
  * Add force reset around calls to actual connection from stubs,
    to ensure compatibility with the version of httplib/urlib2 in
    python 2.7.9.
- Changes from version 1.1.3:
  * Fix python3 headers field
  * Fix boto test
  * Fix new_episodes record mode
  * Fix Windows connectionpool
  * Stub bug
  * Add support for requests 2.5
* Tue Nov  4 2014 hpj@urpla.net
- version 1.1.2: initial build
